@@ -1,10 +1,10 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.57';
+$Geo::Address::Formatter::VERSION = '1.58';
 use strict;
 use warnings;
-
+use feature qw(say);
 use Clone qw(clone);
 use Data::Dumper;
 use File::Basename qw(dirname);
@@ -214,7 +214,7 @@ sub _sanity_cleaning {
     my $rh_components = shift || return;
     
     if ( defined($rh_components->{'postcode'}) ){
-        
+
         if ( length($rh_components->{'postcode'}) > 20){
             delete $rh_components->{'postcode'};
         }
@@ -222,6 +222,9 @@ sub _sanity_cleaning {
               # sometimes OSM has postcode ranges
               delete $rh_components->{'postcode'};
         }
+        elsif ($rh_components->{'postcode'} =~ m/^(\d{5}),\d{5}/){
+            $rh_components->{'postcode'} = $1;
+        }        
     }
 
     # catch values containing URLs
@@ -509,7 +512,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.57
+version 1.58
 
 =head1 SYNOPSIS
 
